==> cppad_2017.00.00.4.orig.tar.gz: cppad-20170000.4/doc/_optimize_xml.js <==
var list_across0 = [
'_contents_xml.htm',
'_reference.xml',
'_index.xml',
'_search_xml.htm',
'_external.xml'
];
var list_up0 = [
'cppad.xml',
'adfun.xml',
'optimize.xml'
];
var list_down2 = [
'install.xml',
'introduction.xml',
'ad.xml',
'adfun.xml',
'preprocessor.xml',
'multi_thread.xml',
'utility.xml',
'ipopt_solve.xml',
'example.xml',
'speed.xml',
'appendix.xml'
];
var list_down1 = [
'independent.xml',
'funconstruct.xml',
'dependent.xml',
'abort_recording.xml',
'seq_property.xml',
'funeval.xml',
'drivers.xml',
'funcheck.xml',
'optimize.xml',
'check_for_nan.xml'
];
var list_down0 = [
'optimize_forward_active.cpp.xml',
'optimize_reverse_active.cpp.xml',
'optimize_compare_op.cpp.xml',
'optimize_print_for.cpp.xml',
'optimize_conditional_skip.cpp.xml',
'optimize_nest_conditional.cpp.xml',
'optimize_cumulative_sum.cpp.xml'
];
var list_current0 = [
'optimize.xml#Syntax',
'optimize.xml#Purpose',
'optimize.xml#f',
'optimize.xml#options',
'optimize.xml#options.no_conditional_skip',
'optimize.xml#options.no_compare_op',
'optimize.xml#options.no_print_for_op',
'optimize.xml#Examples',
'optimize.xml#Efficiency',
'optimize.xml#Speed Testing',
'optimize.xml#Atomic Functions',
'optimize.xml#Atomic Functions.rev_sparse_jac',
'optimize.xml#Atomic Functions.nan',
'optimize.xml#Checking Optimization'
];
function choose_across0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_across0[index-1];
}
function choose_up0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_up0[index-1];
}
function choose_down2(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down2[index-1];
}
function choose_down1(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down1[index-1];
}
function choose_down0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down0[index-1];
}
function choose_current0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_current0[index-1];
}

==> cppad_2018.00.00.0.orig.tar.gz: cppad-20180000.0/doc/_optimize_xml.js <==
var list_across0 = [
'_contents_xml.htm',
'_reference.xml',
'_index.xml',
'_search_xml.htm',
'_external.xml'
];
var list_up0 = [
'cppad.xml',
'adfun.xml',
'optimize.xml'
];
var list_down2 = [
'install.xml',
'introduction.xml',
'ad.xml',
'adfun.xml',
'preprocessor.xml',
'multi_thread.xml',
'utility.xml',
'ipopt_solve.xml',
'example.xml',
'speed.xml',
'appendix.xml'
];
var list_down1 = [
'record_adfun.xml',
'drivers.xml',
'forward.xml',
'reverse.xml',
'sparsity_pattern.xml',
'sparse_derivative.xml',
'optimize.xml',
'abs_normal.xml',
'funcheck.xml',
'check_for_nan.xml'
];
var list_down0 = [
'optimize_forward_active.cpp.xml',
'optimize_reverse_active.cpp.xml',
'optimize_compare_op.cpp.xml',
'optimize_print_for.cpp.xml',
'optimize_conditional_skip.cpp.xml',
'optimize_nest_conditional.cpp.xml',
'optimize_cumulative_sum.cpp.xml'
];
var list_current0 = [
'optimize.xml#Syntax',
'optimize.xml#Purpose',
'optimize.xml#f',
'optimize.xml#options',
'optimize.xml#options.no_conditional_skip',
'optimize.xml#options.no_compare_op',
'optimize.xml#options.no_print_for_op',
'optimize.xml#Examples',
'optimize.xml#Efficiency',
'optimize.xml#Speed Testing',
'optimize.xml#Atomic Functions',
'optimize.xml#Atomic Functions.rev_sparse_jac',
'optimize.xml#Atomic Functions.nan',
'optimize.xml#Checking Optimization'
];
function choose_across0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_across0[index-1];
}
function choose_up0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_up0[index-1];
}
function choose_down2(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down2[index-1];
}
function choose_down1(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down1[index-1];
}
function choose_down0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down0[index-1];
}
function choose_current0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_current0[index-1];
}
